<?php
/**
 * Plugin Name: EasySEO - Woo Product Replacement (EasyToolsWP)
 * Description: Adds a tab to the product editor for setting a replacement product and shows a popup on the frontend if the product is not available.
 * Version: 1.0
 * Author: EasyToolsWP.com
 */

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

// Add a new tab to the product editor
add_filter('woocommerce_product_data_tabs', 'wc_add_product_replacement_tab');

function wc_add_product_replacement_tab($tabs) {
    $tabs['replacement_product'] = array(
        'label'    => __('Replacement Product', 'wc-product-replacement'),
        'target'   => 'replacement_product_data',
        'class'    => array('show_if_simple', 'show_if_variable'),
        'priority' => 21,
    );
    return $tabs;
}

// Add content to the new tab
add_action('woocommerce_product_data_panels', 'wc_add_product_replacement_panel');

function wc_add_product_replacement_panel() {
    global $post;
    
    $enabled = get_post_meta($post->ID, '_product_replacement_enabled', true);
    $replacement_product_id = get_post_meta($post->ID, '_product_replacement_product', true);
    $popup_message = get_post_meta($post->ID, '_product_replacement_popup_message', true);
    $view_product_text = get_post_meta($post->ID, '_product_replacement_view_product_text', true);

    // Get all products
    $products = get_posts(array(
        'post_type' => 'product',
        'posts_per_page' => -1
    ));
    
    $options = array();
    foreach ($products as $product) {
        $options[$product->ID] = $product->post_title;
    }

    ?>
    <div id="replacement_product_data" class="panel woocommerce_options_panel">
        <div class="options_group">
            <?php
            woocommerce_wp_checkbox(array(
                'id' => '_product_replacement_enabled',
                'label' => __('Enable Product Replacement', 'wc-product-replacement'),
                'description' => __('Check this box if you want to enable a replacement product for this product.', 'wc-product-replacement'),
                'value' => $enabled
            ));

            woocommerce_wp_select(array(
                'id' => '_product_replacement_product',
                'label' => __('Replacement Product', 'wc-product-replacement'),
                'options' => $options,
                'value' => $replacement_product_id
            ));

            woocommerce_wp_text_input(array(
                'id' => '_product_replacement_popup_message',
                'label' => __('Popup Message', 'wc-product-replacement'),
                'description' => __('Text to display in the popup when the product is not available.', 'wc-product-replacement'),
                'value' => $popup_message,
                'placeholder' => __('This product is no longer available, we recommend this product:', 'wc-product-replacement')
            ));

            woocommerce_wp_text_input(array(
                'id' => '_product_replacement_view_product_text',
                'label' => __('View Product Button Text', 'wc-product-replacement'),
                'description' => __('Text for the "View Product" button in the popup.', 'wc-product-replacement'),
                'value' => $view_product_text,
                'placeholder' => __('View Product', 'wc-product-replacement')
            ));
            ?>
        </div>
    </div>
    <?php
}

// Save custom field data
add_action('woocommerce_process_product_meta', 'wc_save_product_replacement_field');

function wc_save_product_replacement_field($post_id) {
    $enabled = isset($_POST['_product_replacement_enabled']) ? 'yes' : 'no';
    update_post_meta($post_id, '_product_replacement_enabled', $enabled);
    
    if (isset($_POST['_product_replacement_product'])) {
        update_post_meta($post_id, '_product_replacement_product', intval($_POST['_product_replacement_product']));
    }

    if (isset($_POST['_product_replacement_popup_message'])) {
        update_post_meta($post_id, '_product_replacement_popup_message', sanitize_text_field($_POST['_product_replacement_popup_message']));
    }

    if (isset($_POST['_product_replacement_view_product_text'])) {
        update_post_meta($post_id, '_product_replacement_view_product_text', sanitize_text_field($_POST['_product_replacement_view_product_text']));
    }
}

// Display popup on frontend if product is not available
add_action('wp_footer', 'wc_display_replacement_popup');

function wc_display_replacement_popup() {
    if (!is_product()) {
        return;
    }

    global $post;
    
    $enabled = get_post_meta($post->ID, '_product_replacement_enabled', true);
    
    if ($enabled === 'yes') {
        $replacement_product_id = get_post_meta($post->ID, '_product_replacement_product', true);
        $popup_message = get_post_meta($post->ID, '_product_replacement_popup_message', true);
        $view_product_text = get_post_meta($post->ID, '_product_replacement_view_product_text', true);

        if ($replacement_product_id) {
            $replacement_product = get_post($replacement_product_id);
            $replacement_product_title = $replacement_product->post_title;
            $replacement_product_excerpt = get_post_field('post_excerpt', $replacement_product_id);
            $replacement_product_thumbnail = get_the_post_thumbnail($replacement_product_id, 'thumbnail');

            // Enqueue jQuery and custom JavaScript for popup
            wp_enqueue_script('wc-product-replacement-js', plugin_dir_url(__FILE__) . 'wc-product-replacement.js', array('jquery'), '1.0', true);
            wp_enqueue_style('wc-product-replacement-css', plugin_dir_url(__FILE__) . 'wc-product-replacement.css');

            $popup_message = !empty($popup_message) ? esc_html($popup_message) : __('This product is no longer available, we recommend this product:', 'wc-product-replacement');
            $view_product_text = !empty($view_product_text) ? esc_html($view_product_text) : __('View Product', 'wc-product-replacement');

            echo '<div id="product-replacement-popup" class="hidden">
                    <div class="popup-overlay"></div>
                    <div class="popup-content">
                        <h2>' . esc_html($popup_message) . '</h2>
                        <div class="replacement-product">
                            <div class="product-image">' . $replacement_product_thumbnail . '</div>
                            <div class="product-details">
                                <h3>' . esc_html($replacement_product_title) . '</h3>
                                <p>' . esc_html($replacement_product_excerpt) . '</p>
                                <a href="' . esc_url(get_permalink($replacement_product_id)) . '" class="button">' . esc_html($view_product_text) . '</a>
                            </div>
                        </div>
                    </div>
                </div>';
        }
    }
}

// Add inline CSS and JavaScript to the footer
function wc_add_inline_styles_and_scripts() {
    ?>
    <style>
        .hidden {
            display: none;
        }
        #product-replacement-popup {
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background: rgba(0, 0, 0, 0.7); /* Dark semi-transparent background */
            display: flex;
            align-items: center;
            justify-content: center;
            z-index: 9999; /* Ensure this is higher than the overlay */
        }
        .popup-content {
            background: #fff;
            padding: 20px;
            border-radius: 8px;
            max-width: 600px;
            width: 90%;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.2);
            position: relative; /* Ensure z-index works */
            z-index: 10000; /* Ensure this is higher than the overlay */
        }
        .popup-overlay {
            position: absolute;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background: rgba(0, 0, 0, 0.5);
            z-index: 9998; /* Lower than the popup */
        }
        .replacement-product {
            display: flex;
            align-items: flex-start; /* Align items to the start */
            padding-top: 10px;
        }
        .product-image {
            flex: 0 0 120px; /* Fixed width for the image */
            margin-right: 20px;
            border: 1px solid #ddd;
            border-radius: 4px;
            overflow: hidden; /* Ensure the image doesn’t overflow the container */
        }
        .product-image img {
            width: 100%;
            height: auto;
            display: block;
        }
        .product-details {
            flex: 1;
        }
        .product-details h3 {
            margin: 0 0 10px;
            font-size: 18px;
        }
        .product-details p {
            margin: 0 0 15px;
            font-size: 14px;
            color: #666;
        }
        .popup-content a.button {
            display: inline-block;
            background-color: #0073aa;
            color: #fff;
            padding: 10px 20px;
            text-decoration: none;
            border-radius: 4px;
            font-weight: bold;
        }
        .popup-content a.button:hover {
            background-color: #005177;
        }
    </style>
    <script>
        jQuery(document).ready(function($) {
            $('#product-replacement-popup').removeClass('hidden');
            
            $(document).on('click', '.popup-overlay', function() {
                $('#product-replacement-popup').addClass('hidden');
            });
        });
    </script>
    <?php
}
add_action('wp_footer', 'wc_add_inline_styles_and_scripts');